summaryrefslogtreecommitdiffstats
path: root/sys/netinet6/ipsec.c
diff options
context:
space:
mode:
authorume <ume@FreeBSD.org>2004-01-13 05:39:07 +0000
committerume <ume@FreeBSD.org>2004-01-13 05:39:07 +0000
commit1012c19191db10049b26de7225117ed77f83124f (patch)
treea3461f80c970acb34ef39cbecce9842ee8e4164e /sys/netinet6/ipsec.c
parentfca4bcad4df2afc09ad2cd123822672a80ea5ca4 (diff)
downloadFreeBSD-src-1012c19191db10049b26de7225117ed77f83124f.zip
FreeBSD-src-1012c19191db10049b26de7225117ed77f83124f.tar.gz
correct spelling
Submitted by: "Bjoern A. Zeeb" <bzeeb+freebsd@zabbadoz.net> Reviewed by: itojun
Diffstat (limited to 'sys/netinet6/ipsec.c')
-rw-r--r--sys/netinet6/ipsec.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/sys/netinet6/ipsec.c b/sys/netinet6/ipsec.c
index 917fa33..240cc29 100644
--- a/sys/netinet6/ipsec.c
+++ b/sys/netinet6/ipsec.c
@@ -1,5 +1,5 @@
/* $FreeBSD$ */
-/* $KAME: ipsec.c,v 1.204 2003/09/19 10:53:38 jinmei Exp $ */
+/* $KAME: ipsec.c,v 1.207 2004/01/13 03:30:42 itojun Exp $ */
/*
* Copyright (C) 1995, 1996, 1997, and 1998 WIDE Project.
@@ -469,7 +469,7 @@ ipsec4_getpolicybysock(m, dir, so, error)
if (currsp == NULL)
panic("ipsec4_getpolicybysock: currsp is NULL.");
/* when privilieged socket */
if (pcbsp->priv) {
switch (currsp->policy) {
case IPSEC_POLICY_BYPASS:
@@ -512,7 +512,7 @@ ipsec4_getpolicybysock(m, dir, so, error)
/* NOTREACHED */
}
- /* when non-privilieged socket */
+ /* when non-privileged socket */
/* look for a policy in SPD */
if (ipsec_setspidx_mbuf(&spidx, AF_INET, m, 1) == 0 &&
(kernsp = key_allocsp(tag, &spidx, dir)) != NULL) {
@@ -529,7 +529,7 @@ ipsec4_getpolicybysock(m, dir, so, error)
switch (currsp->policy) {
case IPSEC_POLICY_BYPASS:
ipseclog((LOG_ERR, "ipsec4_getpolicybysock: "
- "Illegal policy for non-priviliged defined %d\n",
+ "Illegal policy for non-privileged defined %d\n",
currsp->policy));
*error = EINVAL;
return NULL;
@@ -678,7 +678,7 @@ ipsec6_getpolicybysock(m, dir, so, error)
if (currsp == NULL)
panic("ipsec6_getpolicybysock: currsp is NULL.");
/* when privilieged socket */
if (pcbsp->priv) {
switch (currsp->policy) {
case IPSEC_POLICY_BYPASS:
@@ -721,7 +721,7 @@ ipsec6_getpolicybysock(m, dir, so, error)
/* NOTREACHED */
}
- /* when non-privilieged socket */
+ /* when non-privileged socket */
/* look for a policy in SPD */
if (ipsec_setspidx_mbuf(&spidx, AF_INET6, m, 1) == 0 &&
(kernsp = key_allocsp(tag, &spidx, dir)) != NULL) {
@@ -738,7 +738,7 @@ ipsec6_getpolicybysock(m, dir, so, error)
switch (currsp->policy) {
case IPSEC_POLICY_BYPASS:
ipseclog((LOG_ERR, "ipsec6_getpolicybysock: "
- "Illegal policy for non-priviliged defined %d\n",
+ "Illegal policy for non-privileged defined %d\n",
currsp->policy));
*error = EINVAL;
return NULL;
@@ -469,7 +469,7 @@ ipsec4_getpolicybysock(m, dir, so, error)
if (currsp == NULL)
panic("ipsec4_getpolicybysock: currsp is NULL.");
- /* when privilieged socket */
+ /* when privileged socket */
if (pcbsp->priv) {
switch (currsp->policy) {
@@ -678,7 +678,7 @@ ipsec6_getpolicybysock(m, dir, so, error)
if (currsp == NULL)
panic("ipsec6_getpolicybysock: currsp is NULL.");
- /* when privilieged socket */
+ /* when privileged socket */
if (pcbsp->priv) {
switch (currsp->policy) {
OpenPOWER on IntegriCloud